@@ -566,7 +566,9 @@ class InsightImporter(metaclass=abc.ABCMeta):
                 setattr(reference_insight, field_name, getattr(insight, field_name))
 
     @classmethod
-    def add_optional_fields(cls, insight: ProductInsight, product: Product):
+    def add_optional_fields(  # noqa: B027
+        cls, insight: ProductInsight, product: Product
+    ):
         """Overwrite this method in children classes to add optional fields.
 
         The `campaign` field should be populated here.
@@ -912,33 +914,6 @@ class StoreInsightImporter(InsightImporter):
             yield insight
 
 
-class PackagingInsightImporter(InsightImporter):
-    @staticmethod
-    def get_type() -> InsightType:
-        return InsightType.packaging
-
-    @staticmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
-        return {PredictionType.packaging}
-
-    @classmethod
-    def is_conflicting_insight(
-        cls, candidate: ProductInsight, reference: ProductInsight
-    ) -> bool:
-        return candidate.value_tag == reference.value_tag
-
-    @classmethod
-    def generate_candidates(
-        cls,
-        product: Product,
-        predictions: List[Prediction],
-    ) -> Iterator[ProductInsight]:
-        for prediction in predictions:
-            insight = ProductInsight(**prediction.to_dict())
-            insight.automatic_processing = True
-            yield insight
-
-
 def is_valid_product_prediction(
     prediction: Prediction, product: Optional[Product] = None
 ) -> bool:
@@ -1033,7 +1008,7 @@ def import_product_predictions(
     return batch_insert(PredictionModel, to_import, 50)
 
 
-IMPORTERS: List[Type[InsightImporter]] = [
+IMPORTERS: List[Type] = [
     PackagerCodeInsightImporter,
     LabelInsightImporter,
     CategoryImporter,
@@ -1041,7 +1016,6 @@ IMPORTERS: List[Type[InsightImporter]] = [
     ExpirationDateImporter,
     BrandInsightImporter,
     StoreInsightImporter,
-    PackagingInsightImporter,
 ]
 
 
